iflow.integration package
=========================

Submodules
----------

iflow.integration.couplings module
----------------------------------

.. automodule:: iflow.integration.couplings
   :members:
   :undoc-members:
   :show-inheritance:

iflow.integration.divergences module
------------------------------------

.. automodule:: iflow.integration.divergences
   :members:
   :undoc-members:
   :show-inheritance:

iflow.integration.integrator module
-----------------------------------

.. automodule:: iflow.integration.integrator
   :members:
   :undoc-members:
   :show-inheritance:

   .. autoclass:: Integrator
      :members:

iflow.integration.sinkhorn module
---------------------------------

.. automodule:: iflow.integration.sinkhorn
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: iflow.integration
   :members:
   :undoc-members:
   :show-inheritance:
